X-Git-Url: https://git.saurik.com/wxWidgets.git/blobdiff_plain/78d14f80e9a72041ede52c30d912ec5cef21b1b3..6cc78259af5f54b52b53523e8c9a22ec33a46060:/contrib/src/xrc/xh_gauge.cpp

diff --git a/contrib/src/xrc/xh_gauge.cpp b/contrib/src/xrc/xh_gauge.cpp
index dec1db540e..852f7bbd65 100644
--- a/contrib/src/xrc/xh_gauge.cpp
+++ b/contrib/src/xrc/xh_gauge.cpp
@@ -1,6 +1,6 @@
 /////////////////////////////////////////////////////////////////////////////
 // Name:        xh_gauge.cpp
 // Purpose:     XML resource for wxGauge
 // Author:      Bob Mitchell
 // Created:     2000/03/21
 // RCS-ID:      $Id$
@@ -24,51 +24,51 @@
 
 #if wxUSE_GAUGE
 
+IMPLEMENT_DYNAMIC_CLASS(wxGaugeXmlHandler, wxXmlResourceHandler)
+
 wxGaugeXmlHandler::wxGaugeXmlHandler() 
 : wxXmlResourceHandler() 
 {
-    ADD_STYLE( wxGA_HORIZONTAL );
-    ADD_STYLE( wxGA_VERTICAL );
-    ADD_STYLE( wxGA_PROGRESSBAR );
-    ADD_STYLE( wxGA_SMOOTH );   // windows only
+    XRC_ADD_STYLE(wxGA_HORIZONTAL);
+    XRC_ADD_STYLE(wxGA_VERTICAL);
+    XRC_ADD_STYLE(wxGA_PROGRESSBAR);
+    XRC_ADD_STYLE(wxGA_SMOOTH);   // windows only
     AddWindowStyles();
 }
 
 wxObject *wxGaugeXmlHandler::DoCreateResource()
 { 
-    wxGauge *control = new wxGauge(m_parentAsWindow,
-                                    GetID(),
-                                    GetLong( wxT("range"), wxGAUGE_DEFAULT_RANGE), 
-                                    GetPosition(), GetSize(),
-                                    GetStyle(),
-                                    wxDefaultValidator,
-                                    GetName()
-                                    );
+    XRC_MAKE_INSTANCE(control, wxGauge)
+
+    control->Create(m_parentAsWindow,
+                    GetID(),
+                    GetLong(wxT("range"), wxGAUGE_DEFAULT_RANGE), 
+                    GetPosition(), GetSize(),
+                    GetStyle(),
+                    wxDefaultValidator,
+                    GetName());
 
-    if( HasParam( wxT("value") ))
+    if( HasParam(wxT("value")))
     {
-        control->SetValue( GetLong( wxT("value") ));
+        control->SetValue(GetLong(wxT("value")));
     }
-    if( HasParam( wxT("shadow") ))
+    if( HasParam(wxT("shadow")))
     {
-        control->SetShadowWidth( GetDimension( wxT("shadow") ));
+        control->SetShadowWidth(GetDimension(wxT("shadow")));
     }
-    if( HasParam( wxT("bezel") ))
+    if( HasParam(wxT("bezel")))
     {
-        control->SetBezelFace( GetDimension( wxT("bezel") ));
+        control->SetBezelFace(GetDimension(wxT("bezel")));
     }
 
     SetupWindow(control);
-    
+
     return control;
 }
 
-
-
 bool wxGaugeXmlHandler::CanHandle(wxXmlNode *node)
 {
     return IsOfClass(node, wxT("wxGauge"));
 }
 
-
 #endif // wxUSE_GAUGE
@@ -1,6 +1,6 @@
 /////////////////////////////////////////////////////////////////////////////
 // Name:        xh_gauge.cpp
-// Purpose:     XML resource for wxGauge
+// Purpose:     XRC resource for wxGauge
 // Author:      Bob Mitchell
 // Created:     2000/03/21